@@ -27,7 +27,6 @@ class TestHydroBASINS:
         dom = self.geoserver.select_hybas_domain(bbox)
         assert dom == "ar"
 
-    @pytest.mark.xfail(reason="OWSLib>0.24.1 is needed.")
     def test_get_hydrobasins_location_wfs(self, tmp_path):
         lake_winnipeg = (
             -98.03575958286369,
@@ -41,7 +40,6 @@ class TestHydroBASINS:
         assert geom.bounds == (-99.2731, 50.3603, -96.2578, 53.8705)
         np.testing.assert_almost_equal(geom.area, 3.2530867)
 
-    @pytest.mark.xfail(reason="OWSLib>0.24.1 is needed.")
     def test_get_hydrobasins_attributes_wfs(self, tmp_path):
         rio_grande = (-80.475, 8.4)
         resp = self.geoserver.get_hydrobasins_location_wfs(
@@ -65,7 +63,6 @@ class TestHydroBASINS:
             np.array([[-80.8542, 8.2459, -80.1375, 8.7004]]),
         )
 
-    @pytest.mark.xfail(reason="OWSLib>0.24.1 is needed.")
     def test_hydrobasins_upstream_aggregate(self, tmp_path):
         puerto_cortes = (-83.525, 8.96, -83.520, 8.97)
         resp = self.geoserver.get_hydrobasins_location_wfs(
@@ -92,7 +89,6 @@ class TestHydroRouting:
     gpd = pytest.importorskip("geopandas")
     sgeo = pytest.importorskip("shapely.geometry")
 
-    @pytest.mark.xfail(reason="OWSLib>0.24.1 is needed.")
     def test_hydro_routing_locations(self, tmp_path):
         lake_winnipeg = (
             -98.03575958286369,
@@ -116,7 +112,6 @@ class TestHydroRouting:
         assert len(gdf) == 11415
 
     @pytest.mark.slow
-    @pytest.mark.xfail(reason="OWSLib>0.24.1 is needed.")
     def test_hydro_routing_upstream(self, tmp_path):
         amadjuak = (-71.225, 65.05, -71.220, 65.10)
         resp = self.geoserver.get_hydro_routing_location_wfs(
@@ -139,7 +134,6 @@ class TestWFS:
     gpd = pytest.importorskip("geopandas")
     sgeo = pytest.importorskip("shapely.geometry")
 
-    @pytest.mark.xfail(reason="OWSLib>0.24.1 is needed.")
     def test_get_location_wfs_point(self, tmp_path):
         las_vegas = (-115.136389, 36.175)
         usa_admin_bounds = "public:usa_admin_boundaries"
@@ -205,9 +199,9 @@ class TestWCS:
                 rf.close()
                 with self.rasterio.open(rf.name) as src:
                     assert src.width == 650
-                    assert src.height == 745
-                    np.testing.assert_array_equal(
-                        src.lnglat(), (-106.64193764047552, 52.1564202369763)
+                    assert src.height == 744
+                    np.testing.assert_allclose(
+                        src.lnglat(), (-106.641957, 52.156555), rtol=1e-5
                     )
                     data = src.read()
                     assert np.unique(data).tolist() == [1, 5, 8, 10, 14, 15, 16, 17, 18]
